@@ -111,9 +111,6 @@ setup(migratorContext *ctx, char *argv0, bool live_check)
 {
 	char		exec_path[MAXPGPATH];	/* full path to my executable */
 
-	/* disallow execution by the root user	*/
-	pg_free(get_user_id(ctx));
-
 	/*
 	 * make sure the user has a clean environment, otherwise, we may confuse
 	 * libpq when we connect to one (or both) of the servers.
